@@ -76,7 +76,7 @@ void DetailDialog::updateDetails()
         return;
     }
 
-    icon->setPixmap(DesktopIcon(item->logLine()->logLevel()->icon()));
+    icon->setPixmap(item->logLine()->logLevel()->icon());
 
     header->setText(item->logLine()->formattedText());
 
@@ -122,8 +122,8 @@ void DetailDialog::moveToItem(int direction)
         return;
     }
 
-    logViewWidget->setItemSelected(item, false);
-    logViewWidget->setItemSelected(destinationItem, true);
+    item->setSelected(false);
+    destinationItem->setSelected(true);
     logViewWidget->scrollToItem(destinationItem);
 
     updateDetails();
